@@ -1,21 +1,21 @@
 // -*- c++ -*-
-/* $Id: init.cc,v 1.1 2003/11/04 18:35:53 mxpxpod Exp $ */
+/* $Id$ */
 
 /* init.cc
  *
  * Copyright 2001      Free Software Foundation
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -25,8 +25,7 @@
 #include <gtkmm/main.h>
 #include <libpanelappletmmconfig.h> //For LIBPANELAPPLETMM_VERSION
 
-#include <libgnome/gnome-program.h>
-#include <gnome.h>
+#include <bonobo/bonobo-main.h>
 
 namespace Gnome
 {
@@ -38,7 +37,7 @@ void init(const Glib::ustring& app_id, const Glib::ustring& app_version, int arg
 {
   Gtk::Main::init_gtkmm_internals(); //Sets up the g type system and the Glib::wrap() table.
   wrap_init(); //Tells the Glib::wrap() table about the libpanelappletmm classes.
-  gnome_program_init(app_id.c_str(), app_version.c_str(), LIBGNOMEUI_MODULE, argc, argv, GNOME_CLIENT_PARAM_SM_CONNECT, FALSE, GNOME_PARAM_NONE);
+  bonobo_init(&argc, argv);
 }
 
 } //namespace Panel
