@@ -1,4 +1,4 @@
-/* $Id: generate_defs_libpanelapplet.cc,v 1.1 2003/11/04 18:36:01 mxpxpod Exp $ */
+/* $Id$ */
 
 /* generate_defs_gnomevfs.h
  *
@@ -12,14 +12,14 @@
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "gtkmm_generate_extra_defs/generate_extra_defs.h"
+#include "glibmm_generate_extra_defs/generate_extra_defs.h"
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 #include <gtk/gtk.h>
